summaryrefslogtreecommitdiffstats
path: root/content/browser/download/byte_stream.h
diff options
context:
space:
mode:
authorrdsmith@chromium.org <rdsmith@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-04 18:20:56 +0000
committerrdsmith@chromium.org <rdsmith@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-04 18:20:56 +0000
commitd7db4f62b576074b5b5f62d156e335855dc51bdb (patch)
treeab1dbcbdf199ac0a8eaec3e2ad49753d216d42b3 /content/browser/download/byte_stream.h
parentf7bc735b65da49b5df9fb82a69dcbab08ebb1061 (diff)
downloadchromium_src-d7db4f62b576074b5b5f62d156e335855dc51bdb.zip
chromium_src-d7db4f62b576074b5b5f62d156e335855dc51bdb.tar.gz
chromium_src-d7db4f62b576074b5b5f62d156e335855dc51bdb.tar.bz2
Use ByteStream in downloads system to decouple source and sink.
BUG=123192 BUG=93006 BUG=111588 Review URL: https://chromiumcodereview.appspot.com/10392111 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@140328 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/browser/download/byte_stream.h')
-rw-r--r--content/browser/download/byte_stream.h26
1 files changed, 14 insertions, 12 deletions
diff --git a/content/browser/download/byte_stream.h b/content/browser/download/byte_stream.h
index 8265b8d..f5be75a 100644
--- a/content/browser/download/byte_stream.h
+++ b/content/browser/download/byte_stream.h
@@ -26,15 +26,15 @@ namespace content {
// sink, which may be on different threads. It is intended to be the
// only connection between source and sink; they need have no
// direct awareness of each other aside from the byte stream. The source and
// the sink have different interfaces to a byte stream, |ByteStreamInput|
// and |ByteStreamOutput|. A pair of connected interfaces is generated by
// calling |CreateByteStream|.
//
// The source adds bytes to the bytestream via |ByteStreamInput::Write|
// and the sink retrieves bytes already written via |ByteStreamOutput::Read|.
//
// When the source has no more data to add, it will call
// |ByteStreamInput::Close| to indicate that. Errors at the source
// are indicated to the sink via a non-DOWNLOAD_INTERRUPT_REASON_NONE code.
//
// Normally the source is not managed after the relationship is setup;
@@ -58,9 +58,9 @@ namespace content {
//
// Class methods are virtual to allow mocking for tests; these classes
// aren't intended to be base classes for other classes.
-class CONTENT_EXPORT ByteStreamInput {
+class CONTENT_EXPORT ByteStreamWriter {
public:
- virtual ~ByteStreamInput() = 0;
+ virtual ~ByteStreamWriter() = 0;
// Always adds the data passed into the ByteStream. Returns true
// if more data may be added without exceeding the class limit
@@ -75,21 +75,22 @@ public:
// Register a callback to be called when the stream transitions from
// full to having space available. The callback will always be
// called on the task runner associated with the ByteStreamInput.
// This callback will only be called if a call to Write has previously
// returned false (i.e. the ByteStream has been filled).
// Multiple calls to this function are supported, though note that it
// is the callers responsibility to handle races with space becoming
// available (i.e. in the case of that race either of the before
// or after callbacks may be called).
+ // The callback will not be called after ByteStreamWriter destruction.
virtual void RegisterCallback(const base::Closure& source_callback) = 0;
};
-class CONTENT_EXPORT ByteStreamOutput {
+class CONTENT_EXPORT ByteStreamReader {
public:
enum StreamState { STREAM_EMPTY, STREAM_HAS_DATA, STREAM_COMPLETE };
- virtual ~ByteStreamOutput() = 0;
+ virtual ~ByteStreamReader() = 0;
// Returns STREAM_EMPTY if there is no data on the ByteStream and
// Close() has not been called, and STREAM_COMPLETE if there
@@ -109,6 +110,7 @@ class CONTENT_EXPORT ByteStreamOutput {
// though note that it is the callers responsibility to handle races
// with data becoming available (i.e. in the case of that race
// either of the before or after callbacks may be called).
+ // The callback will not be called after ByteStreamReader destruction.
virtual void RegisterCallback(const base::Closure& sink_callback) = 0;
};
@@ -116,8 +118,8 @@ CONTENT_EXPORT void CreateByteStream(
scoped_refptr<base::SequencedTaskRunner> input_task_runner,
scoped_refptr<base::SequencedTaskRunner> output_task_runner,
size_t buffer_size,
- scoped_ptr<ByteStreamInput>* input,
- scoped_ptr<ByteStreamOutput>* output);
+ scoped_ptr<ByteStreamWriter>* input,
+ scoped_ptr<ByteStreamReader>* output);
} // namespace content
@@ -26,15 +26,15 @@ namespace content {
// only connection between source and sink; they need have no
// direct awareness of each other aside from the byte stream. The source and
-// the sink have different interfaces to a byte stream, |ByteStreamInput|
-// and |ByteStreamOutput|. A pair of connected interfaces is generated by
+// the sink have different interfaces to a byte stream, |ByteStreamWriter|
+// and |ByteStreamReader|. A pair of connected interfaces is generated by
// calling |CreateByteStream|.
//
@@ -26,15 +26,15 @@ namespace content {
// calling |CreateByteStream|.
//
-// The source adds bytes to the bytestream via |ByteStreamInput::Write|
-// and the sink retrieves bytes already written via |ByteStreamOutput::Read|.
+// The source adds bytes to the bytestream via |ByteStreamWriter::Write|
+// and the sink retrieves bytes already written via |ByteStreamReader::Read|.
//
// When the source has no more data to add, it will call
@@ -26,15 +26,15 @@ namespace content {
//
// When the source has no more data to add, it will call
-// |ByteStreamInput::Close| to indicate that. Errors at the source
+// |ByteStreamWriter::Close| to indicate that. Errors at the source
// are indicated to the sink via a non-DOWNLOAD_INTERRUPT_REASON_NONE code.
//
@@ -75,21 +75,22 @@ public:
// Register a callback to be called when the stream transitions from
// full to having space available. The callback will always be
- // called on the task runner associated with the ByteStreamInput.
+ // called on the task runner associated with the ByteStreamWriter.
// This callback will only be called if a call to Write has previously
// returned false (i.e. the ByteStream has been filled).